@@ -171,7 +171,8 @@ setMethod("genePlot",signature(object="CuffGene"),.plot)
 	#print(dat)
 	p<-ggplot(dat,aes(x="",y=fpkm,fill=tracking_id))
 	
-	p<- p + geom_bar(stat="identity",position="fill",line="black")
+	p<- p + geom_bar(stat="identity",position="fill",color="black")
+
 	
 	p<- p + coord_polar(theta='y')
 	
